bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge Nôt ## 32. Aventiure
___________________________________________________ #### Aventivre wie bloedelin #### erslagen wart
###### 1921 | ### Bloedelines recken | di waren alle gar ### mit tvsent halspergen | hvben si sich dar ### da danchwart mit den knehten | ob dem thisse saz ### da hvb sich vnder helden | der allergrozeste haz
###### 1922 | ### also der herre bloedelin | fver di thisse gie ### danchwart der marschalch | in vlizechliche enpfie ### willechomen her ce hvse | min her bloedelin ### ia wundert mich der maere | waz sol disiv rede sin
###### 1923 | ### ia ne dverfet ir mich niht grvezen | so sprach blodelin ### wan diz chomen daz mine | daz mvz din ende sin ### dvrch hagenen dinen brvder | der sifriden slvch ### des engiltest du hi cen hivnen | vnd ander degene genvch
###### 1924 | ### neina herre bloedelin | so sprach do danchwart ### so moeht vns wol balde | riwen disiv hovevart ### ich was ein wenich kindelin | do sifrit vlos den lip ### ine weiz niht waz mir wizzet | des kvenech eceln wip
###### 1925 | ### ia ne weiz ich dir der maere | niht ce sagene ### ez taten dine mage | gventher vnde hagene ### nv wert ivch vil ellenden | ir chvennet niht genesen ### ir mvezet mit dem tode | pfant daz criemhilde wesen
###### 1926 | ### so ne welt ir niht erwinden | so sprach danchwart ### so riwet mich min vlehen | daz waere baz gespart ### der snelle degen chvene | von dem thisse spranch ### er zoch ein scharpfez waffen | daz was michel vnde lanch
###### 1927 | ### do slvch er blodeline | einen swinden swertes slach ### daz im daz hovbet schiere | vor den fvezen gelach ### daz si din morgengabe | sprach danchwart der degen ### zv nvdvnges brvete | der dv mit minnen woldest pflegen
###### 1928 | ### man mach si morgen mehelen | einem anderm man ### wil er di brvtmiete | dem wirt alsam getan ### ein vil getriwer hivne | het im daz geseit ### daz im div chveneginne | riet so groziv leit
###### 1929 | ### do sahen bloedelines man | ir herre lach erslagen ### do ne wolden si den gesten | niht langer daz vertragen ### mit vf erbvrten swerten | si sprvngen fver div chint ### in grimmigem mvote | daz gerav vil manigen sint
###### 1930 | ### vil lvte rief do danchwart | daz gesinde allez an ### ir seht wol edeln chnehte | wi ez wil vmbe gan ### nv wert ivch vil ellenden | deiswar des gat vns not ### swi vns div edele crimhilt | so rehte gvetlich enbot
###### 1931 | ### di niht swert en heten | di reichten fver di banch ### vnde hvben von den fvezen | vil manegen shalmel lanch ### der bvrgonden knehte | in wolden niht vertragen ### da wart von swaeren stvelen | dvrch helme bveln vil geslagen
###### 1932 | ### wi grimme sich do werten | div ellendn chint ### si triben vz dem hvse | di gevaffenten sint ### doch beleip ir tot darinne | fvnf hvndert oder baz ### do was daz ingesinde | von blvte rot vnde naz
###### 1933 | ### disiv starchen maere | wurden dan geseit ### den eceln recken | ez was in grimme leit ### daz erslagen waere | blodel vnd sine man ### daz het hagen brvder | mit den knehten getan
###### 1934 | ### e ez div chvneginne erfvende | di hivnen dvrch ir haz ### der garte sich zwei tvsent | oder dannoch baz ### si giengen zv den knehten | daz mvs et also wesen ### vnde liezen des gesindes | ninder einen genesen
###### 1935 | ### di vngetriwen brahten | fver das hvs ein michel her ### di ellenden knehte | di stvnden wol ce wer ### waz half ir baldez ellen | si mvsen ligen tot ### darnach in chvrcen stvnden | hvb sich ein vreislichiv not
###### 1936 | ### hi mveget ir hoeren wunder | bi vngefvoge sagen ### nivn tvsent knehte | di lagen tot erslagen ### darveber ritter zwelfe | der danchwartes man ### man sah in alterseine | noch bi den vianden stan
###### 1937 | ### der schal der was geswiftet | der doz der was gelegen ### do blichte veber ahsel | danchwart der degen ### er sprah owe der frivnde | di ich verlorn han ### nv mvz ich leider eine | bi minen fianden stan
###### 1938 | ### div swert genote vielen | vf sin eines lip ### daz mvse sit beweinen | vil maneges heldes wip ### den schilt den rvcht er hoher | den vezel nider baz ### do frvmt er vil der ringe | mit blvote vliezende naz
###### 1939 | ### so we mir dirre leide | sprach aldrianes chint ### nv wichet hivnen reckn | ir lat mich an den wint ### daz der lvft erchvele | mich stvrmenmveden man ### do sah man den rechen | vil hart herliche gan
###### 1940 | ### also der strites mvede | vz dem hvse spranch ### waz iteniwer swerte | vf sinem helm erchlanch ### di niht gesehen heten | waz wunders tet sin hant ### di sprvngen hin engegene | dem von bvergonden lant
###### 1941 | ### nv wolde got sprach danchwart | moeht ich den boten han ### der minen brvder hagenen | chvnde wizen lan ### daz ich vor disen rechen | sten in solher not ### der hvlfe mir von hinnen | oder er gelaege bi mir tot
###### 1942 | ### do sprachen hivnen recken | der bot mvstv sin ### so wir dich tragen toten | fver den brvder din ### so siht im erste leide | der gvntheres man ### dv hast dem chvenege ecel | so grozen schaden hi getan
###### 1943 | ### er sprach nv lat daz drewen | vnde wichet hoher baz ### ia getvn ich etelichem | noch di ringe naz ### ich wil div maere selbe | hin ce hove sagen ### vnde wil ovh minen herren | minen grozen chvmber chlagen
###### 1944 | ### er leidete sich so sere | den eceln man ### daz si in mit den swerten | torsten niht bestan ### do shvzen si der gere | so vil in sinen rant ### daz er in dvrch di swaere | mvse lazen von der hant
###### 1945 | ### do wanden si in betwingen | do er niht schildes trvch ### hey waz er tiefer wunden | dvrch di shilde slvch ### des mvse vor im strvchen | vil manich chvener man ### darvmbe lop vil grozen | der starche danchwart gewan
###### 1946 | ### ze beiden sinen siten | sprvngen si im zv ### ia chom ir islicher | in den strit ze frv ### do gi er vor den vienden | als ein eberswin ### ce walde tvt vor hvnden | wi moht er chvener gesin
###### 1947 | ### sin vart wart erniwet | von heizem blvte naz ### ia ne chvnde ein einech recke | gestriten nimmer baz ### sinen vianden | danne er het getan ### man sach den hagenen brvder | ce hove herlichen gan
###### 1948 | ### trvhsaezen vnde shenchen | di horten swerte chlanch ### vil maneger do daz trinchen | von der hende swanch ### vnde etesliche spise | di man ze hove trvch ### do chom im vor der stiegen | der starchen viende genvch
###### 1949 | ### wi nv ir trvhsaezen | sprach der mvede degen ### ia soldet ir der geste | vil gvetliche pflegen ### vnde soldet ir den herren | gvte spise tragen ### vnde liezet et mich den minen herren | div maere rehte sagen
###### 1950 | ### swelher im dvrch sin ellen | fver di stiege spranch ### der slvch er eteslichem | so grimmen swertes swanch ### daz si dvrch di vorhte | vf hoher mvsen stan ### ez het sin starchen ellen | vil michel wunder gatan

<<< Übersicht <<< vorige Seite nächste Seite >>>